@@ -7,10 +7,10 @@ jsToolBar.prototype.elements.link.open_url = 'popup_link.php';
 jsToolBar.prototype.elements.link.popup = function (args) {
 	window.the_toolbar = this;
 	args = args || '';
-	
+
 	this.elements.link.data = {};
 	var url = this.elements.link.open_url+args;
-	
+
 	var p_win = window.open(url,'dc_popup',
 	'alwaysRaised=yes,dependent=yes,toolbar=yes,height=420,width=520,'+
 	'menubar=no,resizable=yes,scrollbars=yes,status=no');
@@ -21,17 +21,17 @@ jsToolBar.prototype.elements.link.fn.wiki = function() {
 };
 jsToolBar.prototype.elements.link.fncall.wiki = function() {
 	var data = this.elements.link.data;
-	
+
 	if (data.href == '') { return; }
-	
+
 	var etag = '|'+data.href;
 	if (data.hreflang) { etag += '|'+data.hreflang; }
-	
+
 	if (data.title) {
 		if (!data.hreflang) { etag += '|'; }
 		etag += '|'+data.title;
 	}
-	
+
 	if (data.content) {
 		this.encloseSelection('['+data.content,etag+']');
 	} else {
@@ -44,16 +44,16 @@ jsToolBar.prototype.elements.link.fn.xhtml = function() {
 };
 jsToolBar.prototype.elements.link.fncall.xhtml = function() {
 	var data = this.elements.link.data;
-	
+
 	if (data.href == '') { return; }
-	
+
 	var stag = '<a href="'+data.href+'"';
-	
+
 	if (data.hreflang) { stag += ' hreflang="'+data.hreflang+'"'; }
 	if (data.title) { stag += ' title="'+data.title+'"'; }
 	stag += '>';
 	var etag = '</a>';
-	
+
 	if (data.content) {
 		this.encloseSelection('','',function() {
 			return stag + data.content + etag;
@@ -67,22 +67,22 @@ jsToolBar.prototype.elements.link.fn.wysiwyg = function() {
 	var href, title, hreflang;
 	href = title = hreflang = '';
 	hreflang = this.elements.link.default_hreflang;
-	
+
 	var a = this.getAncestor();
-	
+
 	if (a.tagName == 'a') {
 		href= a.tag.href || '';
 		title = a.tag.title || '';
 		hreflang = a.tag.hreflang || '';
 	}
-	
+
 	this.elements.link.popup.call(this,'?href='+href+'&hreflang='+hreflang+'&title='+title);
 };
 jsToolBar.prototype.elements.link.fncall.wysiwyg = function() {
 	var data = this.elements.link.data;
-	
+
 	var a = this.getAncestor();
-	
+
 	if (a.tagName == 'a') {
 		if (data.href == '') {
 			// Remove link
@@ -105,7 +105,7 @@ jsToolBar.prototype.elements.link.fncall.wysiwyg = function() {
 			return;
 		}
 	}
-	
+
 	// Create link
 	if (data.content) {
 		var n = document.createTextNode(data.content);
@@ -122,7 +122,7 @@ jsToolBar.prototype.elements.link.fncall.wysiwyg = function() {
 jsToolBar.prototype.getAncestor = function() {
 	var res = {};
 	var range, commonAncestorContainer;
-	
+
 	if (this.iwin.getSelection) { //gecko
 		var selection = this.iwin.getSelection();
 		range = selection.getRangeAt(0);
@@ -134,16 +134,16 @@ jsToolBar.prototype.getAncestor = function() {
 		range = this.iwin.document.selection.createRange();
 		commonAncestorContainer = range.parentElement();
 	}
-	
+
 	var ancestorTagName = commonAncestorContainer.tagName.toLowerCase();
 	while (ancestorTagName!='a' && ancestorTagName!='body') {
 		commonAncestorContainer = commonAncestorContainer.parentNode;
 		ancestorTagName = commonAncestorContainer.tagName.toLowerCase();
 	}
-	
+
 	res.tag = commonAncestorContainer;
 	res.tagName = ancestorTagName;
-	
+
 	return res;
 };
 
@@ -159,7 +159,7 @@ jsToolBar.prototype.elements.img_select = {
 	popup: function() {
 		window.the_toolbar = this;
 		this.elements.img_select.data = {};
-		
+
 		var p_win = window.open(this.elements.img_select.open_url,'dc_popup',
 		'alwaysRaised=yes,dependent=yes,toolbar=yes,height=500,width=760,'+
 		'menubar=no,resizable=yes,scrollbars=yes,status=no');
@@ -171,11 +171,11 @@ jsToolBar.prototype.elements.img_select.fn.wiki = function() {
 jsToolBar.prototype.elements.img_select.fncall.wiki = function() {
 	var d = this.elements.img_select.data;
 	if (d.src == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		var alt = (str) ? str : d.title;
 		var res = '(('+d.src+'|'+alt;
-		
+
 		if (d.alignment == 'left') {
 			res += '|L';
 		} else if (d.alignment == 'right') {
@@ -185,18 +185,18 @@ jsToolBar.prototype.elements.img_select.fncall.wiki = function() {
 		} else if (d.description) {
 			res += '|';
 		}
-		
+
 		if (d.description) {
 			res += '|'+d.description;
 		}
-		
+
 		res += '))';
-		
+
 		if (d.link) {
 			var ltitle = (alt) ? '||'+alt : '';
 			res = '['+res+'|'+d.url+ltitle+']';
 		}
-		
+
 		return res;
 	});
 };
@@ -206,11 +206,11 @@ jsToolBar.prototype.elements.img_select.fn.xhtml = function() {
 jsToolBar.prototype.elements.img_select.fncall.xhtml = function() {
 	var d = this.elements.img_select.data;
 	if (d.src == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		var alt = (str) ? str : d.title;
 		var res = '<img src="'+d.src+'" alt="'+alt.replace('&','&amp;').replace('>','&gt;').replace('<','&lt;').replace('"','&quot;')+'"';
-		
+
 		if (d.alignment == 'left') {
 			res += ' style="float: left; margin: 0 1em 1em 0;"';
 		} else if (d.alignment == 'right') {
@@ -218,18 +218,18 @@ jsToolBar.prototype.elements.img_select.fncall.xhtml = function() {
 		} else if (d.alignment == 'center') {
 			res += ' style="margin: 0 auto; display: block;"';
 		}
-		
+
 		if (d.description) {
 			res += ' title="'+d.description.replace('&','&amp;').replace('>','&gt;').replace('<','&lt;').replace('"','&quot;')+'"';
 		}
-		
+
 		res += ' />';
-		
+
 		if (d.link) {
 			var ltitle = (alt) ? ' title="'+alt.replace('&','&amp;').replace('>','&gt;').replace('<','&lt;').replace('"','&quot;')+'"' : '';
 			res = '<a href="'+d.url+'"'+ltitle+'>'+res+'</a>';
 		}
-		
+
 		return res;
 	});
 };
@@ -237,11 +237,11 @@ jsToolBar.prototype.elements.img_select.fncall.xhtml = function() {
 jsToolBar.prototype.elements.img.fn.wysiwyg = function() {
 	var src = this.elements.img.prompt.call(this);
 	if (!src) { return; }
-	
+
 	var img = this.iwin.document.createElement('img');
 	img.src = src;
 	img.setAttribute('alt',this.getSelectedText());
-	
+
 	this.insertNode(img);
 };
 
@@ -252,12 +252,12 @@ jsToolBar.prototype.elements.img_select.fncall.wysiwyg = function() {
 	var d = this.elements.img_select.data;
 	var alt = (this.getSelectedText()) ? this.getSelectedText() : d.title;
 	if (d.src == undefined) { return; }
-	
+
 	var img = this.iwin.document.createElement('img');
 	img.src = d.src;
 	img.setAttribute('alt',alt);
-	
-	
+
+
 	if (d.alignment == 'left') {
 		if (img.style.styleFloat != undefined) {
 			img.style.styleFloat = 'left';
@@ -285,11 +285,11 @@ jsToolBar.prototype.elements.img_select.fncall.wysiwyg = function() {
 		img.style.marginLeft = 'auto';
 		img.style.display = 'block';
 	}
-	
+
 	if (d.description) {
 		img.setAttribute('title',d.description);
 	}
-	
+
 	if (d.link) {
 		var a = this.iwin.document.createElement('a');
 		a.href = d.url;
@@ -308,7 +308,7 @@ jsToolBar.prototype.elements.mp3_insert = { fncall: {}, data: {} };
 jsToolBar.prototype.elements.mp3_insert.fncall.wiki = function() {
 	var d = this.elements.mp3_insert.data;
 	if (d.player == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		return '\n///html\n' + d.player + '///\n';
 	});
@@ -316,7 +316,7 @@ jsToolBar.prototype.elements.mp3_insert.fncall.wiki = function() {
 jsToolBar.prototype.elements.mp3_insert.fncall.xhtml = function() {
 	var d = this.elements.mp3_insert.data;
 	if (d.player == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		return '\n' + d.player + '\n';
 	});
@@ -330,7 +330,7 @@ jsToolBar.prototype.elements.flv_insert = { fncall: {}, data: {} };
 jsToolBar.prototype.elements.flv_insert.fncall.wiki = function() {
 	var d = this.elements.flv_insert.data;
 	if (d.player == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		return '\n///html\n' + d.player + '///\n';
 	});
@@ -338,7 +338,7 @@ jsToolBar.prototype.elements.flv_insert.fncall.wiki = function() {
 jsToolBar.prototype.elements.flv_insert.fncall.xhtml = function() {
 	var d = this.elements.flv_insert.data;
 	if (d.player == undefined) { return; }
-	
+
 	this.encloseSelection('','',function(str) {
 		return '\n' + d.player + '\n';
 	});
@@ -359,7 +359,7 @@ jsToolBar.prototype.elements.post_link = {
 	popup: function() {
 		window.the_toolbar = this;
 		this.elements.img_select.data = {};
-		
+
 		var p_win = window.open(this.elements.post_link.open_url,'dc_popup',
 		'alwaysRaised=yes,dependent=yes,toolbar=yes,height=500,width=760,'+
 		'menubar=no,resizable=yes,scrollbars=yes,status=no');
@@ -376,4 +376,11 @@ jsToolBar.prototype.elements.post_link.fn.wysiwyg = function() {
 };
 
 // Last space element
-jsToolBar.prototype.elements.space3 = {type: 'space'};
\ No newline at end of file
+jsToolBar.prototype.elements.space3 = {
+	type:'space',
+	format:{
+		wysiwyg:true,
+		wiki:true,
+		xhtml:true
+	}
+};
