@@ -18,29 +18,30 @@ class dcSpamFilter
 	public $active = true;
 	public $order = 100;
 	public $auto_delete = false;
-	
+	public $help = null;
+
 	protected $has_gui = false;
 	protected $gui_url = null;
-	
+
 	protected $core;
-	
+
 	/**
 	Object constructor
-	
+
 	@param	core		<b>dcCore</b>		Dotclear core object
 	*/
 	public function __construct($core)
 	{
 		$this->core =& $core;
 		$this->setInfo();
-		
+
 		if (!$this->name) {
 			$this->name = get_class($this);
 		}
-		
+
 		$this->gui_url = 'plugin.php?p=antispam&f='.get_class($this);
 	}
-	
+
 	/**
 	This method is called by the constructor and allows you to change some
 	object properties without overloading object constructor.
@@ -49,15 +50,15 @@ class dcSpamFilter
 	{
 		$this->description = __('No description');
 	}
-	
+
 	/**
 	This method should return if a comment is a spam or not. If it returns true
 	or false, execution of next filters will be stoped. If should return nothing
 	to let next filters apply.
-	
+
 	Your filter should also fill $status variable with its own information if
 	comment is a spam.
-	
+
 	@param		type		<b>string</b>		Comment type (comment or trackback)
 	@param		author	<b>string</b>		Comment author
 	@param		email	<b>string</b>		Comment author email
@@ -71,11 +72,11 @@ class dcSpamFilter
 	public function isSpam($type,$author,$email,$site,$ip,$content,$post_id,&$status)
 	{
 	}
-	
+
 	/**
 	This method is called when a non-spam (ham) comment becomes spam or when a
 	spam becomes a ham.
-	
+
 	@param	type		<b>string</b>		Comment type (comment or trackback)
 	@param	filter	<b>string</b>		Filter name
 	@param	author	<b>string</b>		Comment author
@@ -90,12 +91,12 @@ class dcSpamFilter
 	public function trainFilter($status,$filter,$type,$author,$email,$site,$ip,$content,$rs)
 	{
 	}
-	
+
 	/**
 	This method returns filter status message. You can overload this method to
 	return a custom message. Message is shown in comment details and in
 	comments list.
-	
+
 	@param	status		<b>string</b>		Filter status.
 	@param	comment_id	<b>record</b>		Comment record
 	@return	<b>string</b>
@@ -104,46 +105,46 @@ class dcSpamFilter
 	{
 		return sprintf(__('Filtered by %1$s (%2$s)'),$this->guiLink(),$status);
 	}
-	
+
 	/**
 	This method is called when you enter filter configuration. Your class should
 	have $has_gui property set to "true" to enable GUI.
-	
+
 	In this method you should put everything related to filter configuration.
 	$url variable is the URL of GUI <i>unescaped</i>.
-	
+
 	@param	url		<b>string</b>		GUI URL.
 	*/
 	public function gui($url)
 	{
 	}
-	
+
 	public function hasGUI()
 	{
 		if (!$this->core->auth->check('admin',$this->core->blog->id)) {
 			return false;
 		}
-		
+
 		if (!$this->has_gui) {
 			return false;
 		}
-		
+
 		return true;
 	}
-	
+
 	public function guiURL()
 	{
 		if (!$this->hasGui()) {
 			return false;
 		}
-		
+
 		return $this->gui_url;
 	}
-	
+
 	/**
 	Returns a link to filter GUI if exists or only filter name if has_gui
 	property is false.
-	
+
 	@return	<b>string</b>
 	*/
 	public function guiLink()
@@ -154,8 +155,11 @@ class dcSpamFilter
 		} else {
 			$link = '%1$s';
 		}
-		
+
 		return sprintf($link,$this->name,$url);
 	}
+
+	public function help()
+	{
+	}
 }
-?>
\ No newline at end of file
