@@ -3,7 +3,7 @@
 #
 # This file is part of Antispam, a plugin for Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -42,7 +42,9 @@ try
 		$ts = dt::str('%Y-%m-%d %H:%M:%S',$_POST['ts'],$core->blog->settings->system->blog_timezone);
 
 		dcAntispam::delAllSpam($core,$ts);
-		http::redirect($p_url.'&del=1');
+
+		dcPage::addSuccessNotice(__('Spam comments have been successfully deleted.'));
+		http::redirect($p_url);
 	}
 
 	# Update filters
@@ -88,7 +90,9 @@ try
 		}
 
 		dcAntispam::$filters->saveFilterOpts($filters_opt);
-		http::redirect($p_url.'&upd=1');
+
+		dcPage::addSuccessNotice(__('Filters configuration has been successfully saved.'));
+		http::redirect($p_url);
 	}
 }
 catch (Exception $e)
@@ -98,12 +102,22 @@ catch (Exception $e)
 ?>
 <html>
 <head>
-  <title><?php echo $page_name; ?></title>
+  <title><?php echo ($filter_gui !== false ? sprintf(__('%s configuration'),$filter->name).' - ' : '').$page_name; ?></title>
+  <script type="text/javascript">
+  //<![CDATA[
   <?php
-  echo
-  dcPage::jsToolMan().
-  dcPage::jsPageTabs($default_tab).
-  dcPage::jsLoad('index.php?pf=antispam/antispam.js');
+  echo dcPage::jsVar('dotclear.msg.confirm_spam_delete',__('Are you sure you want to delete all spams?'));
+  ?>
+  //]]>
+  </script>
+  <?php
+  echo dcPage::jsPageTabs($default_tab);
+  $core->auth->user_prefs->addWorkspace('accessibility');
+  if (!$core->auth->user_prefs->accessibility->nodragdrop) {
+	echo
+		dcPage::jsLoad('js/jquery/jquery-ui.custom.js').
+		dcPage::jsLoad('index.php?pf=antispam/antispam.js');
+  }
   ?>
   <link rel="stylesheet" type="text/css" href="index.php?pf=antispam/style.css" />
 </head>
@@ -112,14 +126,30 @@ catch (Exception $e)
 
 if ($filter_gui !== false)
 {
-	echo '<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <a href="'.$p_url.'">'.$page_name.'</a>'.
-		' &rsaquo; <span class="page-title">'.sprintf(__('%s configuration'),$filter->name).'</span></h2>';
+	echo dcPage::breadcrumb(
+		array(
+			__('Plugins') => '',
+			$page_name => $p_url,
+			sprintf(__('%s filter configuration'),$filter->name) => ''
+		)).
+		dcPage::notices();
+
+	echo '<p><a href="plugin.php?p=antispam" class="back">'.__('Back to filters list').'</a></p>';
 
 	echo $filter_gui;
+
+	if ($filter->help) {
+		dcPage::helpBlock($filter->help);
+	}
 }
 else
 {
-	echo '<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <span class="page-title">'.$page_name.'</span></h2>';
+	echo dcPage::breadcrumb(
+		array(
+			__('Plugins') => '',
+			$page_name => ''
+		)).
+		dcPage::notices();
 
 	# Information
 	$spam_count = dcAntispam::countSpam($core);
@@ -130,10 +160,6 @@ else
 	'<form action="'.$p_url.'" method="post" class="fieldset">'.
 	'<h3>'.__('Information').'</h3>';
 
-	if (!empty($_GET['del'])) {
-		echo '<p class="message">'.__('Spam comments have been successfully deleted.').'</p>';
-	}
-
 	echo
 	'<ul class="spaminfo">'.
 	'<li class="spamcount"><a href="comments.php?status=-2">'.__('Junk comments:').'</a> '.
@@ -151,23 +177,24 @@ else
 	}
 	if ($moderationTTL != null && $moderationTTL >=0) {
 		echo '<p>'.sprintf(__('All spam comments older than %s day(s) will be automatically deleted.'), $moderationTTL).' '.
-		__('You can modify this duration in ').
-		'<a href="blog_pref.php"> '.__('Blog preferences').'</a></p>';
+		sprintf(__('You can modify this duration in the %s'),'<a href="blog_pref.php#antispam_moderation_ttl"> '.__('Blog settings').'</a>').
+			'.</p>';
 	}
 	echo '</form>';
 
 
 	# Filters
 	echo
-	'<form action="'.$p_url.'" method="post" class="fieldset">';
+	'<form action="'.$p_url.'" method="post" id="filters-list-form">';
 
 	if (!empty($_GET['upd'])) {
-		echo '<p class="message">'.__('Filters configuration has been successfully saved.').'</p>';
+		dcPage::success(__('Filters configuration has been successfully saved.'));
 	}
 
 	echo
+	'<div class="table-outer">'.
 	'<table class="dragable">'.
-	'<caption>'.__('Available spam filters').'</caption>'.
+	'<caption class="as_h3">'.__('Available spam filters').'</caption>'.
 	'<thead><tr>'.
 	'<th>'.__('Order').'</th>'.
 	'<th>'.__('Active').'</th>'.
@@ -190,17 +217,17 @@ else
 
 		echo
 		'<tr class="line'.($f->active ? '' : ' offline').'" id="f_'.$fid.'">'.
-		'<td class="handle">'.form::field(array('f_order['.$fid.']'),2,5,(string) $i, '', '', false, 'title="'.__('position').'"').'</td>'.
+		'<td class="handle">'.form::field(array('f_order['.$fid.']'),2,5,(string) $i, 'position', '', false, 'title="'.__('position').'"').'</td>'.
 		'<td class="nowrap">'.form::checkbox(array('filters_active[]'),$fid,$f->active, '', '', false, 'title="'.__('Active').'"').'</td>'.
 		'<td class="nowrap">'.form::checkbox(array('filters_auto_del[]'),$fid,$f->auto_delete, '', '', false, 'title="'.__('Auto Del.').'"').'</td>'.
-		'<td class="nowrap" scope="raw">'.$f->name.'</td>'.
+		'<td class="nowrap" scope="row">'.$f->name.'</td>'.
 		'<td class="maximal">'.$f->description.'</td>'.
 		'<td class="status">'.$gui_link.'</td>'.
 		'</tr>';
 		$i++;
 	}
 	echo
-	'</tbody></table>'.
+	'</tbody></table></div>'.
 	'<p>'.form::hidden('filters_order','').
 	$core->formNonce().
 	'<input type="submit" name="filters_upd" value="'.__('Save').'" /></p>'.
@@ -226,8 +253,11 @@ else
 		'<li class="feed"><a href="'.$ham_feed.'">'.__('Published comments RSS feed').'</a></li>'.
 		'</ul>';
 	}
+
+	dcPage::helpBlock('antispam','antispam-filters');
 }
+
 ?>
 
 </body>
-</html>
\ No newline at end of file
+</html>
