@@ -15,6 +15,8 @@ $this->registerModule(
 	/* Name */			"themeEditor",
 	/* Description*/		"Theme Editor",
 	/* Author */			"Olivier Meunier",
-	/* Version */			'1.0'
+	/* Version */			'1.0',
+	array(
+		'type'		=>		'plugin'
+	)
 );
-?>
\ No newline at end of file
